#
# spec file for package cmake
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cmake
Version:        2.8.12.1
Release:        1.1
Url:            http://www.cmake.org/
Source0:        http://www.cmake.org/files/v2.8/%{name}-%{version}.tar.gz
Source1:        cmake.macros
Source2:        opensuse_rules.cmake
Patch2:         cmake-fix-ruby-test.patch
Summary:        Cross-platform, open-source make system
License:        BSD-3-Clause
Group:          Development/Tools/Building
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
%if 0%{?sles_version} != 10
BuildRequires:  libarchive-devel
%endif
BuildRequires:  libexpat-devel
%else
BuildRequires:  expat-devel
%endif
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  zlib-devel

Requires:       make

%description
CMake is a cross-platform, open-source make system

%prep
%setup -q -n %{name}-%{version}
%patch2

%build
export CXXFLAGS="$RPM_OPT_FLAGS"
export CFLAGS="$CXXFLAGS"
./configure \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --docdir=/share/doc/packages/%{name} \
    --mandir=/share/man \
%if 0%{?suse_version} && !0%{?sles_version}
    --system-libs \
%else
    --system-curl \
    --system-expat \
    --system-zlib \
    --system-bzip2 \
    --no-system-libarchive \
%endif
    --parallel=0%jobs \
    --no-qt-gui
make VERBOSE=1 %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
mkdir -p %{buildroot}%{_libdir}/cmake
find %{buildroot}/usr/share/cmake -type f -print0 | xargs -0 chmod 644
cp ChangeLog.manual %{buildroot}/usr/share/doc/packages/%{name}/Changelog
# rpm macros
install -m644 %{SOURCE1} -D %{buildroot}%{_sysconfdir}/rpm/macros.cmake
# buildrules
install -m644 %{SOURCE2} -D %{buildroot}%{_datadir}/cmake/Modules/opensuse_rules.cmake
sed -i \
    -e 's:OPTFLAGS:%{optflags}:g' \
    %{buildroot}%{_datadir}/cmake/Modules/opensuse_rules.cmake

%if 0%{?suse_version} > 1010
%fdupes %{buildroot}/usr/share/cmake
%endif

%files
%defattr(-,root,root)
%{_sysconfdir}/rpm/macros.cmake
%{_bindir}/cpack
%{_bindir}/cmake
%{_bindir}/ctest
%{_bindir}/ccmake
%{_datadir}/cmake
%{_libdir}/cmake
%{_datadir}/aclocal/cmake.m4
%doc %{_datadir}/doc/packages/%{name}
%doc %{_mandir}/man1/cmakepolicies.1.*
%doc %{_mandir}/man1/cmake.1.*
%doc %{_mandir}/man1/ctest.1.*
%doc %{_mandir}/man1/ccmake.1.*
%doc %{_mandir}/man1/cmakecommands.1.*
%doc %{_mandir}/man1/cmakecompat.1.*
%doc %{_mandir}/man1/cmakemodules.1.*
%doc %{_mandir}/man1/cmakeprops.1.*
%doc %{_mandir}/man1/cmakevars.1.*
%doc %{_mandir}/man1/cpack.1.*

%changelog
* Thu Nov  7 2013 vcizek@suse.com
- update to 2.8.12.1
  * Reverts a change in behaviour from older versions caused by a bad
    implementation of a CMake Policy introduced in 2.8.12: CMP0022
    (bnc#849378)
* Wed Nov  6 2013 boris@steki.net
- updated cmake.macros to include installation path for cmake modules
* Tue Oct  8 2013 hrvoje.senjan@gmail.com
- Update to 2.8.12
  * Xcode: Fix test architecture selection for Xcode >= 5
  * Xcode: Teach Tests/BuildDepends to allow LINK_DEPENDS_NO_SHARED failure
  * Xcode: Drop XCODE_DEPEND_HELPER for Xcode >= 5
  * Xcode: Fix OBJECT library support for Xcode 5 (#14254)
  * Genex: Fix processing multiple include directories for relative paths
  * VS: Future-proof Intel project format selection
  * MSVC: Drop /link from executable link lines with Ninja
  * FindCUDA: Always list custom command outputs in their targets
  * FindPNG: Honor old PNG_LIBRARY if provided (#14398)
  * FindHDF5: Fix regression in per-configuration library selection
  * bash-completion: Future-proof --help-*-list "cXXXX version" filtering
  * OS X: Search system SDKs for frameworks
  * Use first custom command for the same output (#14446)
  * MSVC: Fix version test for linking corelibc on Windows CE (#14420)
  * MSVC: Fix WinCE arch family preprocessor symbol (#14436)
  * VS: Use version-specific subsystem for WinCE compiler id (#14440)
  * bootstrap: try better workaround for builds on Linux/HPPA
  * Add differing target property content to policy CMP0022 warning
  * Fix CMP0022 warning when no old-style property is set
  * genex: Fix preprocessing with incomplete content (#14410).
  * cmMakefile: Do not track CMake temporary files.
  * Fix RunCMake.Configure test expectation newline matching
  * Clean up install rules of CMake itself (#14371)
  * OSX: Allow an empty INSTALL_NAME_DIR to override MACOSX_RPATH.
  * FindImageMagick: Find libraries named with HDRI support (#14348)
  * FindTCL: Add BSD paths for Tcl/Tk 8.6
  * VS: Generate ToolsVersion matching each VS version
  * cmMakefile: Do not track configured files known to be temporary
  * CheckC*CompilerFlag: add documentation what to expect from a positive result
  * Fix OLD behavior of CMP0021.
  * try_compile: Extract IMPORTED targets from LINK_DEPENDENT_LIBRARIES
  * try_compile: Extract IMPORTED targets from INTERFACE_LINK_LIBRARIES
  * Genex: Fix evaluation of MAP_IMPORTED_CONFIG_<CONFIG>
  * Fix some whitespace errors in docs.
  * Normalize system directories from the interface target property
  * CPack: Fix a typo in documentation
  * CTest: Fix GTM coverage parsing line offset bug
  * CPackWIX: Add support for custom WiX templates
  * CMakeSystem: include toolchain file after setting CMAKE_HOST_ (#13796)
  * Add support files for C, C++ and ASM for the IAR toolchain.
  * Add regexps for the IAR toolchain to the vendor list.
  * Add IAR to the CMakeDetectC(XX)CompilerID.c(pp).in
  * cmake-gui: use shortcut F only for "Find in Output"
  * Eclipse: fix #14204 and #14205: no file links to directories
  * automoc: add a global AUTOMOC_TARGETS_FOLDER property
  * install: do not strip dll import libraries (#14123)
  * ExportTargets: add one more comment to the generated file.
  * Add documentation for the --graphviz support
  * graphvizoptions: add copyright notice
  * add macros cmake_print_properties() and cmake_print_variables()
  * VS: Detect MSVC compiler id on ARM toolchain
  * Fix spelling and typos (affecting users)
  * Fix spelling and typos (affecting binary data / module messages)
  * Fix spelling and typos (non-binary)
  * Fix spelling and typos (product names)
  * FindwxWidgets: add DOC strings with usual style
  * Explain distribution of Win9x binary on all Windows versions.
  * VS10: add detailed comment about MIDL processing
  * Docs: Update description of CMAKE_(BUILD_TYPE|CONFIGURATION_TYPES)
  * Docs: Clarify that CMAKE_*_(PREFIX|SUFFIX) affect filenames
  * Docs: Clarify wording "flag used" => "flag (to|will) be used"
  * set_property: Do not remove a property when APPENDing nothing
  * Tests/RunCMake: Document stripping of expected output
  * export: Error when exporting a target without a language
  * variable_watch: Store client data as pointers
  * variable_watch: Add a deleter for the client data
  * variable_watch: Match client_data when finding duplicates
  * variable_watch: Allow specifying the data to match in RemoveWatch
  * variable_watch: Prevent making extra entries in the watch map
  * variable_watch: Fix a typo in the error message
  * variable_watch: Don't share memory for callbacks
  * variable_watch: Check newValue for NULL
  * variable_watch: Add test for watching a variable multiple times
  * Do not set CMAKE_MATCH_ variables when not neeeded
  * SelectLibraryConfigurations: Fix for cached <base>_LIBRARY
  * VS: Separate compiler and linker PDB files (#11899, #14062)
  * MSVC: Invoke 'link' directly for executables
  * Ninja: Fix OBJECT_DIR placeholder path conversion
  * VS 10: Escape ; as %%3B in preprocessor definitions (#14073)
  * CTest: Simplify ctest_* command source/build dir lookup
  * get_filename_component: Add explicit unit tests
  * get_filename_component: Add DIRECTORY option (#14091)
  * Xcode: Use explicitFileType to mark source types (#14093)
  * Check{C,CXX}CompilerFlag: Test using C locale (#14102)
  * Windows: Search '/' prefix only when cross compiling (#10994)
  * Recognize ld with toolchain prefix (#13960)
  * VS: Always initialize CMAKE_CONFIGURATION_TYPES in IDE generators
  * Begin post-2.8.11 development
  * Sanitize linker name to parse implicit link line (#14154)
  * VS: Allow /Fa to set AssemblerListingLocation (#14153)
  * Tests/IncludeDirectories: Avoid shared library with no symbols
  * if: Add test for IS_DIRECTORY
  * try_compile: Add test for bad call error cases
  * try_compile: Refactor argument processing
  * variable_watch: Add test for MODIFIED_ACCESS report
  * bootstrap: Compile KWSys SystemTools with UTIME(S|NSAT) values
  * variable_watch: Remove leftover debugging code (#14187)
  * variable_watch: Print accesses as "CMake Debug Log" messages
  * Docs: Clarify CMAKE_PARENT_LIST_FILE (#14194)
  * get_filename_component: Test ABSOLUTE of .. after root component
  * try_compile: Add signature to allow multiple SOURCES
  * enable_language: Clarify documentation
  * Split cmBootstrapCommands.cxx into two sources
  * Document CMAKE_INSTALL_PREFIX in CMAKE_SYSTEM_PREFIX_PATH
  * cmake: Document "-E tar" support for .zip (#14225)
  * FindBoost: Clarify failure on missing 'static' libs (#14235)
  * CMakeDetermineVSServicePack: Improve documentation
  * CMakeDetermineVSServicePack: Add VS 11 update 1 and 2 (#14239)
  * Document ENV syntax as a "variable" (#14245)
  * Embarcadero: Use response files only for includes, objects, and libs
  * Escape target flags taken from COMPILE_OPTIONS
  * Refactor target COMPILE_OPTIONS and COMPILE_FLAGS handling
  * CMakeDetermineVSServicePack: Add VS 11 update 3
  * Document removal of 'register' from flex/bison output
  * VS12: Find proper MSBuild for VSProjectInSubdir test
  * Fortran: Use explicit type in Fortran 90 check
  * project: Document top-level CMakeLists.txt requirement
  * ExternalProject: Document multiple COMMAND lines
  * include: Clarify variable access scope for included file
  * VS: Fix /MAP:mapfile flag mapping (#14282)
  * cmake: On configure error suggest looking at CMake*.log files
  * try_compile: Escape CMAKE_<lang>_FLAGS in test projects (#14268)
  * try_compile: Add COPY_FILE_ERROR option to capture failure
  * FindPNG: Add versioned library names for 1.6 (#14289)
  * cmake: Fix resource leak reported by cppcheck
  * VS,Xcode: Drop incorrect legacy dependency trace (#14291)
  * OS X: Add copyright notices to Darwin-*-Fortran.cmake
  * VS: Avoid leaking child process output back to IDE (#14266)
  * Fix ExportImport test cmp0022NEW build on Watcom
  * add_test: Document test name restrictions (#14298)
  * UseJava: Update notice of copyright by Kitware
  * add_custom_command: Manage backtrace memory correctly (#14299)
  * Teach compiler ABI check to tolerate try_compile COPY_FILE failure
  * Test COMPILE_DEFINITIONS target property get/set/get round-trip
  * Check*CompilerFlag: Document use of CMAKE_REQUIRED_DEFINITIONS (#14309)
  * sha2: Avoid type-punned pointer dereference (#14314)
  * VS 6: Tell BuildDepends test to tolerate ninjadep failure
  * cmMakefile: Do not track configured files known to be temporary
  * libarchive: Update README-CMake.txt for new snapshot
  * libarchive: Include cm_zlib.h to get zlib used by CMake
  * libarchive: Silence API deprecation warnings
  * libarchive: Avoid struct init with variable
  * libarchive: Remove build options not used by CMake
  * libarchive: Backport to CMake 2.8.2
  * VS10: Honor user-specified /SUBSYSTEM: flag (#14326)
  * VS10: Escape include paths in XML project files (#14331)
  * OS X: Search for SDK based on deployment target (#14324)
  * bootstrap: Do not suppress CMAKE_OSX_SYSROOT if CFLAGS have -isysroot (#14324)
  * OS X: Enable command-line build without tools in PATH
  * VS 6,7: Refactor local generators to avoid GetSourceFileWithOutput
  * cmake-gui: Fix build rules for Qt5 on Windows
  * Include cmMakefile.h before cm*Lexer.h to get stdint.h first
  * Skip CTestLimitDashJ test on Borland
  * Add RunCMake.Syntax test to cover argument parsing
  * cmListFileLexer: Fix line number after backslash in string
  * cmListFileLexer: Split normal and legacy unquoted arguments
  * cmListFileArgument: Generalize 'Quoted' bool to 'Delimeter' enum
  * Add RunCMake.Syntax test cases for command invocation styles
  * cmListFileCache: Convert CMake language parser to class
  * Warn about arguments not separated by whitespace
  * Warn about unquoted arguments that look like long brackets
  * cmListFileLexer: Modify flex output to avoid Borland warning
  * Cygwin: Avoid legacy warnings in RunCMake.* tests
  * Update version introducing CMP0021, CMP0022, and CMP0023
  * OS X: Do not default to non-existent deployment target SDK
  * Do not warn about left paren not separated by a space
  * VS: Add support for .NET target framework version
  * Improve documentation for CPACK_PACKAGE_INSTALL_REGISTRY_KEY.
  * Refactor how bundles and frameworks are supported.
  * Xcode: Add support for shared library versioning
  * OS X:  Fix getting of CFBundle LOCATION property.
  * OS X: Add RPATH support for Mac.
  * Xcode: Add rpath support in Xcode generator.
  * OS X: Add support for @rpath in export files.
  * OS X: Add test for rpaths on Mac.
  * OS X: Improvements for getting install name of dylib.
  * OS X: Enable rpath support on Mac OS X when find_library() is used.
  * OS X: Fix regression handling frameworks for Ninja
  * OS X: If necessary, use xcrun to help find otool used to query install names.
  * Xcode: Support XCODE_ATTRIBUTE_ with [variant=<config>] (#12532)
  * FindGTK2: Move check for pangocairo in gtk module
  * FindGTK2: Detect gthread library
  * FindFreetype: Detect Freetype installed by GtkMM installer for win
  * FindGTK2: Do not fail on MSVC11 if vc100 libraries are available
  * FindGTK2: Add GTK2_DEFINITIONS variable
  * SelectLibraryConfigurations: Do not cache the _LIBRARY variable
  * SelectLibraryConfigurations: Use -NOTFOUND instead of copying the vars
  * FindGTK2: Use GTK_XXX_LIBRARY_DEBUG libraries in debug mode
  * FindGTK2: Append _LIBRARY to var name in _GTK2_FIND_LIBRARY
  * FindGTK2: Append _INCLUDE_DIR to var name in _GTK2_FIND_INCLUDE_DIR
  * FindGTK2: Update local changelog
  * FindGTK2: Remove GTK2_SKIP_MARK_AS_ADVANCED option
  * FindGTK2: gthread-2.0 folder does not exist
  * FindGTK2: Detect gmodule library
  * FindGTK2: Detect pangoft2 and pangoxft libraries
  * OpenBSD: Enable ELF parsing and editing (#14241)
  * CPack/NSIS: Obtain path from which to uninstall from registry (#14124)
  * Add support for componentized USER spec file
  * CPackRPM add mechanism to remove path from generated list of file in RPM spec.
  * CPackRPM add /usr/lib64 to the list of builtin to-be-excluded path
  * CPackRPM protect '@' character in filename processed in the spec file.
  * CPackRPM make the changelog line conform to expected format
  * CPackWIX: Handle CPACK_PACKAGE_EXECUTABLES (#13967)
  * FindImageMagick: Find v6 include dir (#14174)
  * OS X: Add Fortran library version flags (#14249)
  * UseJava: Pass sources to javac using response file (#13028)
  * Allow using Java in a cross-compilation toolchain
  * Ninja: use cd /D to set directory on Windows
  * CPackWIX: Fix MSI package layout regression from parent
  * bash-completion: Add -S,-SP options arguments completion
  * bash-completion: Fix/improve generator names extraction
  * Eclipse: Add a missing space in the documentation
  * MinGW: Find mingw32-make included with Code::Blocks IDE (#14302)
  * VS: Add Windows Forms Support
  * VS: Add VS_GLOBAL_ROOTNAMESPACE target property
  * VS: Add Resx configuration to the vcxproj file
  * libarchive 3.1.2 (reduced)
  * cmake-gui: Add search functions for Output window (#9733)
  * cmake-gui: Add search functions to the context menu of the Output widget
  * cmake-gui: Change shortcut of the search field from Ctrl-F to Alt-E
  * cmake-gui: Add function for going to next error message in Output window
  * FindCUDA: Remove duplicate entries from INCLUDE_DIRECTORIES.
  * FindX11: Search in /opt/X11 for OS X 10.8 (#14232)
  * FindCUDA: CUDA_COMPUTE_BUILD_PATH uses relative paths to binary dir.
  * ExternalProject: Allow blank SVN_USERNAME/SVN_PASSWORD (#14128)
  * Xcode: Honor CMAKE_(MODULE|SHARED)_LINKER_FLAGS_<CONFIG> (#14161)
  * UseJava.cmake: fully use cmake_parse_arguments in add_jar
  * FindProtobuf: also find pthread
  * UseJava.cmake: document add_jar compat shim
  * Optimize custom command full-path dependency lookup
  * Add cmake_host_system_information command
  * Add option to use stdout/stderr of original terminal in cmake --build
  * Unify the way the flags of a static library are read
  * Add support for CMAKE_STATIC_LINKER_FLAGS
  * Add CMAKE_STATIC_LINKER_FLAGS to CMakeCommonLanguageInclude
  * Add documentation for the missing CMAKE_*_LINKER_FLAGS_* variables
  * Add additonal tests for the linker flags
  * VS6: Add handling of CMAKE_*_LINKER_FLAGS_<CONFIG> variables
  * VS6: Hardcode id_machine_6 for compiler detection
  * VS10: Do not set the TargetMachine when detecting the compiler
  * VS: Set CMAKE_VS_PLATFORM_NAME for VS7 and VS71 too
  * VS: Replace ArchitectureId with PlatformName
  * VS12: Remove duplicated overload of UseFolderProperty()
  * Fix detection of WinCE SDKs with 64bit verion of CMake
  * VS: Unify how the name of the generator is specified
  * VS10: Add support for assembler code (#11536)
  * WIN: Use COFF file header header for architecture detection (#14083)
  * Improve const-correctness in cmVisualStudioGeneratorOptions
  * Fix setting of the entry point symbol for Windows CE (#14088)
  * Add support for new Windows CE compiler
  * VS11: Add support for Windows CE SDKs
  * CTest: Add test for running many tests in parallel
  * cmDependsC: Collapse relative include paths
  * Add projectDir parameter to GenerateBuildCommand
  * VS: Create parser for Visual Studio .sln files
  * VS: Use .sln parser to build targets in subdirs with msbuild (#13623)
  * VS: Add test for building MSBuild project in subdir
  * ctest_build: Pass projectDir to GenerateBuildCommand
  * Ninja: Make cmcldeps depfile output more consistent with 'ninja -t msvc'
  * CPackWIX: Handle multiple shortcuts in the start menu
  * CPackWIX: Add option to specify the language(s) of the installer
  * CMakeCPack: Provide an upgrade guid for WiX
  * cmMakefile: Refactor AddCMakeDependFile  and AddCMakeOutputFile.
  * Ninja: Track configured files so we can regenerate them.
  * cmMakefile: Track configured files so we can regenerate them (#13582)
  * Add a test to expose a bug with add_custom_command and ninja.
  * Ninja: GlobalNinjaGenerator WriteBuild and WritePhonyBuild non static
  * Ninja: Custom Command file depends don't need to exist before building
  * FindCUDA: Search for libraries in <prefix>/lib/<arch>/nvidida-current.
  * Ninja: Properly convert all paths to unix style before we do set intersection.
  * Ninja: Update BuildDepends test to verify cmcldeps depfiles.
  * FindOpenSSL: Fix spelling of CMAKE_CROSSCOMPILING (#14075)
  * FindOpenGL: simplify OS selection code
  * FindOpenGL: require headers to be found on non-Windows platforms (#13746)
  * Tests: create output files for all memory checkers
  * CTest: use an output file for Valgrind (#14110)
  * CTest: remove unreachable code and CTestTestMemcheckUnknown test
  * Tests: remove code duplication in CTestTestMemCheck tests
  * Tests: verify that memory checker output files are always present
  * CTest: drop suppression for gcc 2.9.6 errors from default Valgrind flags
  * Tests: add test for non-existent Valgrind suppression file
  * CTest: fix comment documenting cmBoundsCheckerParser class
  * Tests: add a test with custom options passed to valgrind
  * CTest: make sure never to report negative test times (#14132)
  * Doc: fix example for FAIL_REGULAR_EXPRESSION
  * CTest: break after first regex match on output
  * Tests: ignore Guard Malloc messages in MemChecker tests
  * CTest: avoid useless changing of directory
  * Tests: fix build of dummy memtester on AIX
  * wizard: fix warnings
  * wizard: simplify control flow
  * cmTarget: drop the unused local typedef LinkLine
  * Tests: ignore GuardMalloc messages on all Apple build, not just XCode ones
  * replace string(... MATCHES "^const$) with string(... STREQUAL "const")
  * Revert "CTest: fix pre and post test commands with spaces" (#13887)
  * FindPNG: improve library detection (#14301)
  * CTest: create one output file per memcheck (#14303)
  * Remove some uses of obsolete 'register' storage specifier
  * Document CMAKE_<LANG>_FLAGS variable (#14305)
  * Make the QtAutomoc test compile with either Qt 4 or Qt 5
  * Add a test for Qt5Automoc
  * Remove an endif() followed by an if() for the same condition.
  * Fix some copyastos in the DetermineRCCompiler file.
  * Test transitive includes from setting the LINK_LIBRARIES property.
  * Test the use of target transitive compile definitions with moc.
  * Fix handling of commas in arbitrary content in genexes.
  * Fix style.
  * Remove unused marker for a variable which is now used.
  * Extract the ProcessArbitraryContent method.
  * Rename the method determining if a genex accepts arbitrary content.
  * Make it possible for any genex to have arbitrary content at the end.
  * Add the JOIN generator expression.
  * Test that linking using the debug keyword to tll works.
  * automoc: Read target defines unconditionally
  * Remove unused typedef.
  * Fix brace indentation.
  * Add EXPORT_NAME property.
  * Remove unused vector population.
  * Sublime: Honor source-level COMPILE_FLAGS property
  * Docs: cmake -G selects a "build system" generator
  * Recognize shared library files with a numerical suffix
  * FindQt4: Fix QUIET failure with Qt 5 but not Qt 4
  * Error on relative path in INCLUDE_DIRECTORIES target property.
  * include_directories: Fix handling of empty or space-only entries
  * CTest: Read CTEST_PARALLEL_LEVEL from environment
  * string: Add MAKE_C_IDENTIFIER subcommand
  * GenerateExportHeader: Add newlines to separate the compiler output.
  * GenerateExportHeader: Allow use of of this macro with MODULEs.
  * file: Add GENERATE command to produce files at generate time
  * Tests/Module/GenerateExportHeader: Test exported free-function
  * Add $<LINK_LANGUAGE> generator expression
  * GenerateExportHeader: Generate only C identifiers as defines
  * Tests/CompileDefinitions: Avoid spaces in defines on VS 6
  * Use the qt5::moc imported target instead of a variable.
  * QtAutomoc: Get the Qt version through the target link interface
  * Fix indentation.
  * VS6: Rename some variables to correspond to config values.
  * Add cmLocalGenerator::GetCompileOptions.
  * Add <LANG>_COMPILER_ID generator expressions.
  * cmTarget: Rename struct to be more re-usable.
  * cmTarget: Rename LinkInterfaceIncludeDirectoriesEntries
  * Add COMPILE_OPTIONS target property.
  * Add target_compile_options command.
  * Introduce target property <LANG>_VISIBILITY_PRESET
  * Add a COMPILE_OPTION for a VISIBILITY_INLINES_HIDDEN target property.
  * Qt4Macros: Allow specifying a TARGET in invokations of macros.
  * Introduce add_compile_options command.
  * Remove unused cmAddDefinitionsCommand::ParseDefinition method.
  * Add some spaces to the INCLUDE_DIRECTORIES documentation.
  * CLI: Suppress the unused warning if the key value pair is cached.
  * Use --sysroot when cross compiling.
  * Add missing 'seen' check for evaluating COMPILE_OPTIONS.
  * Find targets in INTERFACE_COMPILE_OPTIONS when exporting for try_compile.
  * Use a preprocessor loop to manage the valid transitive properties.
  * Generate INTERFACE_COMPILE_OPTIONS on export.
  * Genex: Fix indentation in docs.
  * cmSystemTools: Fix typo in comment.
  * Style: Don't put an else after a return.
  * Add compiler target compile options.
  * QtAutomoc: Fix handling of list separator for compile definitions.
  * QtAutomoc: Use config-dependent compile definitions and includes.
  * De-duplicate version comparison code.
  * Add generator expressions for version comparision.
  * Don't run the WarnUnusedCliUnused test on Windows.
  * Add whitespace after colons in error messages.
  * Add missing return after error report.
  * Genex: Make LINK_LANGUAGE report an error when evaluating link libraries.
  * Genex: Extend EvaluatingLinkLibraries to also check the top target name.
  * Genex: Report error if a target file is needed to evaluate link libraries.
  * Add generator expressions for compiler versions.
  * Split the GeneratorExpression test into a third part.
  * Remove unused variable.
  * Add Target API to determine if an include is a system include.
  * Store system include directories in the cmTarget.
  * Extend the cmTargetPropCommandBase interface property handling.
  * Add a SYSTEM parameter to target_include_directories (#14180)
  * Add entire link interface transitive closure as target depends.
  * Test non-IMPORTED libraries in the INTERFACE of IMPORTED libraries.
  * GenexEval: Add abstracted access to link interface for a target.
  * Introduce the LINK_ONLY generator expression.
  * Introduce the INTERFACE_LINK_LIBRARIES property.
  * Export: Generate INTERFACE_LINK_LIBRARIES property on targets.
  * TLL: Don't populate old link interface if CMP0022 is NEW.
  * Overload cmLocalGenerator::AppendDefines to add a list.
  * Add an overload of cmIDEOptions::AddDefines taking a vector of strings.
  * Refactor cmTarget::GetCompileDefinitions to use an out-vector, not a string.
  * Document some variables for deprecation control.
  * Genex: Make CMP0021 and CMP0022 usable with TARGET_POLICY
  * Revert "Use --sysroot when cross compiling."
  * Add target property debugging for COMPILE_DEFINITIONS
  * Mark qt4_use_modules and qt4_automoc as obsolete.
  * Add the INTERFACE_SYSTEM_INCLUDE_DIRECTORIES target property.
  * Don't add trailing whitespace to error message.
  * Remove TODO to uniq COMPILE_OPTIONS
  * Remove the LINK_LANGUAGE generator expression.
  * Genex: Fix $<CONFIG> with IMPORTED targets and multiple locations.
  * FindQt4: Don't use Qt component _FOUND vars before they're defined (#14286)
  * Add a convenient way to add the includes install dir to the INTERFACE.
  * Use linked frameworks as a source of include directories.
  * target_link_libraries: Add PUBLIC/PRIVATE/INTERFACE keyword signature
  * FindQt4: Re-add QAxServer to the QT_MODULES.
  * FindQt4: Populate the INTERFACE_LINK_LIBRARIES of IMPORTED targets.
  * Genex: Allow relative paths in INSTALL_INTERFACE.
  * cmTarget: Fix property name typo in docs.
  * Docs: Document file(GENERATE) CONDITION as optional.
  * Qt4Macros: Remove unneeded generate CONDITION.
  * Qt4Macros: Remove undefined varible use.
  * Qt4Macros: Simplify some variable population.
  * Docs: Document existing target property debugging options.
  * Docs: Trim trailing whitespace in generated doc.
  * Docs: Generalize and de-duplicate VISIBILITY_PREFIX docs.
  * Docs: Document variables for default visibility values.
  * Export: Fix typo of LINK_INTERFACE_LIBRARIES.
  * cmTarget: Remove duplicates when printing traces of tll signatures
  * cmTarget: Fix iface libraries and languages for static libraries.
  * Genex: Disallow LINKER_LANGUAGE only when used on a static library.
  * install: Remove error condition using INCLUDES DESTINATION without EXPORT.
  * Fix crash on export of target with empty INTERFACE_INCLUDE_DIRECTORIES.
  * Allow target commands to be invoked with no items (#14325).
  * Docs: Fix typo in CMAKE_DEBUG_TARGET_PROPERTIES
  * cmTarget: Add NAME property
  * Export: Process generator expressions from INCLUDES DESTINATION.
  * Add the ALIAS target concept for libraries and executables.
  * Revert "Add compiler target compile options."
  * Genex: Fix segfault when parsing ends with parameter expectation.
  * Add cmake_reset_check_state() macro
  * Use GmakeErrorParser instead of deprecated MakeErrorParser (fixes bug 0013699)
  * variable_watch: Add missing string enumeration entry (#14188)
  * ccmake: Add missing initializers reported by cppcheck
  * libarchive: Fix free() order to avoid accessing freed memory
  * cmcurl: Fix resource leak reported by cppcheck
- Dropped cmake-cmCustomCommand_add_operator=.patch and
  cmake-fix-ImageMagick6.patch, merged upstream
* Wed Sep 11 2013 kkaempf@suse.com
- Fix build for SLE10 (no fdupes)
* Mon Aug 12 2013 tchvatal@suse.com
- One more backslash here.
* Mon Aug 12 2013 tchvatal@suse.com
- Backshlashes were missing in macros.
* Mon Aug 12 2013 tchvatal@suse.com
- Add opensuse_rules.cmake to set the default compiler and linker
  opts. Tweak a bit the macro to not let upstreams twerk with the
  cmake files too much.
* Sun Aug 11 2013 tchvatal@suse.com
- Provide macros.cmake which contains %%cmake macro to reduce
  mess in the spec files.
* Sat Aug  3 2013 hrvoje.senjan@gmail.com
- Update to 2.8.11.2
  * asm support: adapt to changes in CMakeDetectCompiler in 2.8.10
  * SelectLibraryConfigurations: Fix for cached <base>_LIBRARY
  * cmCryptoHash: Increase alignment of HashFile buffer
  * cmcurl: Backport curl bug 1192 fix (#14250)
  * VS12: Add Visual Studio 12 generator (#14251)
  * VS12: Generate flag tables from MSBuild v120 tool files
  * FindBoost: Add -vc120 mangling for VS 12
  * VS: Clarify Visual Studio product year for each version
* Thu Aug  1 2013 vcizek@suse.com
- Drop cmake-disable-builtin-chrpath.diff (bnc#786345)
  The RPATH/RUNPATH bug was fixed in 2.8.0
* Wed Jul 17 2013 vcizek@suse.com
- add missing operator= for cmCustomCommand (bnc#829544)
  * cmake-cmCustomCommand_add_operator=.patch
* Thu Jun 20 2013 tittiatcoke@gmail.com
- Added upstream patch cmake-fix-ImageMagick6.patch
  FindImageMagick: Find v6 include dir (#14174)
  The header files of ImageMagick are now located at
  <prefix>/include/ImageMagick-6 instead of
  <prefix>/include/ImageMagick.
* Sat Jun  8 2013 cgiboudeaux@gmx.com
- Update to 2.8.11.1
  * ExternalData: Do not re-stage staged object files
  * try_compile: Fix quoting of libraries in generated CMakeLists.txt
  * KWSys: Fix SystemTools::FileIsDirectory with long paths (#14176)
  * FindBoost: Fix handling of \ in input paths (#14179)
  * Xcode: Fix framework search paths in STATIC library targets (#14191)
  * Fix test failures caused by regexp-sensitive characters in the build paths
  * include_directories: Fix handling of empty or space-only entries
  * try_compile: Trim whitespace from LINK_LIBRARIES entries
  * cmTarget: Remove some hardcoding of transitive property names.
  * GenexEval: Extract a getLinkedTargetsContent from TargetPropertyNode.
  * GenexEval: Fix evaluation of INCLUDE_DIRECTORIES target property.
  * GenexEval: Test evaluation of INCLUDE_DIRECTORIES target property.
  * FindQt4: Don't fail if certain Qt modules are unavailable.
  * Qt4Macros: Handle Qt ActiveX libraries in qt4_use_modules.
  * Genex: Fix the HEAD target used for evaluated expressions
* Sat May 18 2013 cgiboudeaux@gmx.com
- Update to 2.8.11
  * Targets can specify usage requirements for their consumers such as
    include directories and preprocessor definitions; previously only
    link dependencies were supported.
  * target_link_libraries(myexe yourlib) can now build myexe sources
    with requirements specified by yourlib
  * Added target_include_directories and target_compile_definitions
    commands with PUBLIC/PRIVATE/INTERFACE options
  * Introduced ExternalData Module
  * Keep source trees lightweight by storing data separately
  * Reference data unambiguously from source tree by content hash
  * Fetch on-demand during build from local or remote resources
  * CMake: Sublime Text Generator added that supports both Make and Ninja
  * CMake: Added support for Texas Instruments C6 and up compilers
  * CMake: Improve OpenBSD support
  * CPack: Added Support for 64bit NSIS
  * CPack: Added WiX Package Generator
  * ExternalProject: Will run git fetch less often
  * FindBoost: Major overhaul of searching and result caching
  * FindCUDA: Now has support for separable compilation
  * FindQt4: Overall improvements to finding Qt and importing targets
  * FindSquish: Added support for squish 4
  Full changelog at http://www.kitware.com/blog/home/post/492
  * Drop cmake-endian.patch (Merged upstream)
* Thu Feb 28 2013 schwab@suse.de
- cmake-endian.patch:
  Add support for aarch64.
* Wed Nov 28 2012 cgiboudeaux@gmx.com
- Update to 2.8.10.2
  * Fix kitware#0013691: [Modules] FindGettext.cmake does not set GETTEXT_FOUND on success
  * Fix kitware#0013702: [CMake] CMake crashes when reconfiguring build
  * Fix kitware#0013667: [CMake] Automoc fails to handle Q_INTERFACES
- Drop obsolete patches
* Mon Nov 26 2012 tittiatcoke@gmail.com
- Add cmake-fix-qt-includes.diff to fix the missing qt_include_dir.
  This was reported as cmake regression from 2.8.9 (kitware#0013667).
* Wed Nov 14 2012 idonmez@suse.com
- Add cmake-gettext.patch to fix gettext detection
* Wed Nov  7 2012 cgiboudeaux@gmx.com
- Update to 2.8.10.1 This is a bugfix release
  * Fix kitware#0013651: FindSDL.cmake is broken
  * Fix kitware#0013638: ./configure reports Copyright 2000-2011
  Complete changelog: http://public.kitware.com/Bug/changelog_page.php?version_id=105
* Fri Nov  2 2012 cgiboudeaux@gmx.com
- Update to 2.8.10
  * file(DOWNLOAD now handles "https" URLs -- the pre-built binaries available from Kitware link to OpenSSL
  * Automoc: fix kitware#13572: issue with symbolic links
  * Uniform compiler "id" and version number variables available for nearly all known compilers and platforms
  * New way to arrange exported targets that depend on other targets into "export sets"
  * New generator expressions
  * Generator expressions available in more contexts, namely in the INCLUDE_DIRECTORIES and COMPILE_DEFINITIONS target properties
  See /usr/share/doc/packages/cmake/Changelog for the complete changelog
- Minor spec cleanup
* Tue Aug 14 2012 cgiboudeaux@gmx.com
- Update to 2.8.9
  * See /usr/share/doc/packages/cmake/Changelog for changes
  * Drop cmake-pkgconfig.patch, already upstream
* Wed May 30 2012 coolo@suse.com
- fix the ruby test patch once more to also work with ruby 1.8
* Mon May 14 2012 coolo@suse.com
- vendor-specific does no longer exist with ruby 1.9, so don't use
  it to check vendor support
* Tue Apr 24 2012 idonmez@suse.com
- Add cmake-pkgconfig.patch to fix cmake bug #13125
* Wed Apr 18 2012 cgiboudeaux@gmx.com
- Update to 2.8.8
  - see /usr/share/doc/packages/cmake/Changelog for changes
* Wed Jan 25 2012 cgiboudeaux@gmx.com
- Update to 2.8.7
  - see /usr/share/doc/packages/cmake/Changelog for changes
* Fri Oct 14 2011 puzel@suse.com
- update to 2.8.6
  - see /usr/share/doc/packages/cmake/Changelog for changes
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Jul 29 2011 puzel@novell.com
- update to 2.8.5
  - see /usr/share/doc/packages/cmake/Changelog for changes
* Tue Apr  5 2011 puzel@novell.com
- use --no-system-libarchive for openSUSE < 11.3
* Mon Apr  4 2011 puzel@novell.com
- update to 2.8.4
  - see /usr/share/doc/packages/cmake/Changelog for changes
* Thu Jan 20 2011 dmueller@suse.de
- udpate to 2.8.4-rc1:
  - see /usr/share/doc/packages/cmake/Changelog for changes
- remove fortify patch
* Thu Nov 11 2010 puzel@novell.com
- update to cmake-2.8.3
  - see /usr/share/doc/packages/cmake/Changelog for changes
- drop cmake-FindGTK2-gdk-pixbuf.patch (fixed upstream)
- drop cmake-support-new-python.diff (fixed upstream)
* Tue Sep 14 2010 puzel@novell.com
- add cmake-FindGTK2-gdk-pixbuf.patch (bnc#635439)
* Mon Sep 13 2010 kkaempf@novell.com
- fix build on RHEL/Fedora
* Tue Sep  7 2010 coolo@novell.com
- support new python 2.7
* Tue Jul 20 2010 puzel@novell.com
- update to cmake-2.8.2
  - notable changes:
  - CPack: Add native BZip2 support
  - ExternalProject: Support .zip and .bz2 archives, MD5 verification
  - GetPrerequisites: Provide an override hook
  - Recognize ARM ABI/EABI with GNU compilers
  - Recognize Clang compiler
  - Search basic directories on "Generic" platform
  - Support compression with 'cmake -E tar'
  - a lot of bugfixes
* Thu Jun 10 2010 dimstar@opensuse.org
- Fix build on Fedora, by not using defaultdocdir. It does not
  match the forced installation path on configure.
* Thu Jun  3 2010 dimstar@opensuse.org
- No fdupes on non-suse platforms and SLE10.
* Tue May 18 2010 puzel@novell.com
- split cmake-gui into different specfile so that cmake
  build does not depend on libqt4
* Thu Mar 18 2010 puzel@novell.com
- update to cmake 2.8.1 (final)
  - Add a new search path for MPICH2
  - Add .git .bzr and .hg to the list of default CPack ignore
    directories.
  - CTest: Do not hide test GUI windows (fixes 2.8.0 regression)
  - Documentation: Clarify CMAKE_MODULE_PATH variable
  - FindQt4: Add support for QtDeclartive module
  - FortranCInterface: Fix PathScale detection
* Wed Feb 24 2010 dmueller@suse.de
- update to cmake 2.8.1 (rc3):
  * many bugfixes
  - CTest: Setup command-line dashboard support with Git
  - CPack: Improve RPM spec files
  - CTest: Improve host system introspection
  - FindCUDA: Respect CUDA version differences
  - FindCURL: Find import libraries on Windows
  - FindGTK2: Look in fink locations on Mac OS X
  - FindJNI: Honor find_package() REQUIRED and QUIET options
  - FindOpenSSL: Fix MinGW support
  - FindPythonLibs: Look in config for static library
  - FindQt4: Misc enhancements, sync with KDE vesion
  - FindX11: Improve documentation
  - link_directories(): Treat relative paths consistently (CMP0015)
  - Modernize FindLibXslt and FindLibXml.cmake
  - UseQt4: Provide dependencies only for static Qt (#10021)
* Sat Feb 13 2010 dmueller@suse.de
- fix fortify related static buffer overflows (not exploitable)
* Fri Nov 27 2009 puzel@suse.cz
- update to cmake-2.8.0
  - noteworthy changes sice 2.6.4:
  - cmake-gui supports multi-state values options.
  - CMake now has cmake --build command that can build any CMake generated
    project from the command line.
  - CTest supports running tests in parallel with a -j N option.
  - It is now possible to use DESTDIR in CPack for any CMake based projects
    giving more flexibility on the final path names.
  - Depend scanning is now much faster with makefiles.
  - Many FindQt4 improvements to stay working with current Qt releases
  - FindBoost has been updated to work with the most recent boost releases.
  - see /usr/share/doc/packages/cmake/Changelog for all changes
- drop ibm-java-paths.diff, cmake-2.6.0-use_shared_python_lib.patch and
  cmake-2.6.0-use_intree_xmlrpc.patch - fixed upstream
* Mon May  4 2009 puzel@suse.cz
- updated to 2.6.4
  - Fix: ctest system information was not always correct on linux
  - Fix transitive linking of imported libraries
  - Fix CDash only submit with ctest_submit
  - Fix scope issue with CMAKE_CURRENT_LIST_FILE  and macros
  - Fix crash in include_directories
  - Do not warn if LIBPATH is not set for nmake
  - No longer mark header files as HEADER_FILE_ONLY automatically,
    this gets rid of the ugly red marks in Visual Stuido
  - Enforce unique binary directories
  - Clarify docs of old *_OUTPUT_PATH vars
  - Fix svn update logic for modified files
  - Add get_filename_component(... REALPATH)
* Mon May  4 2009 dmueller@suse.de
- add %%_libdir/cmake to the file list
* Wed Mar 11 2009 dmueller@suse.de
- build fixes for non-suse distros
* Tue Mar  3 2009 puzel@suse.cz
- update to 2.6.3
  - add parenthetical expressions to if
  - improve scoping of policies (see cmake_policy and CMP0011)
  - teach find_package more config file locations
  - many improved Find scripts in Modules
  - added an unset command
  - better reporting when nmake compiler environment is not correct
  - lots of bug fixes
- use fdupes to remove duplicate files
* Mon Dec 22 2008 ro@suse.de
- Fix java detection also for ia64 s390 s390x
* Mon Oct 13 2008 dmueller@suse.de
- Fix Detection of IBM Java (needed for PPC build of Java modules)
* Tue Sep 30 2008 puzel@suse.cz
- update to 2.6.2:
  - Fixed: cpack did not work when sym-linked after install
  - Add beta BundleUtilities.cmake file
  - CPackRPM 7435 fixes to add optional post-install
  - Fixed: FindBoost versioned find not working
  - Fix FindCurses to be able to work without ncurses.h
  - FindQt4 fixed: add a bit more documentation and add ability
    to specify extra flags to lupdate.
  - Fixed: make llvm-gcc work, by explicitely excluding
    "llvm-" from _CMAKE_TOOLCHAIN_PREFIX
  - Fixed: OS X Framework support: extensionless headers were
    being ignored when specified as public headers
  - Fix documentation in CheckCCompilerFlag.cmake
  - Add better version support to find_package command
  - Fix Xcode debug not working
  - Add VERSION compare to if command
  - Make FindThreads sete THREADS_FOUND
  - Deb cpack generator sets Installed-Size for the package
  - Do not add an empty /D"" at the end of VS 6 .dsp compile lines
  - Recognize /MAP in VS 7 and greater
  - Add new policy CMP0009 - GLOB_RECURSE should not follow symlinks by
    default
  - many other bugfixes - see changelog
* Sun Aug  3 2008 dmueller@suse.de
- update to 2.6.1:
  * Fix for bug 7427, preinstall target name hard coded
* Wed Jul 23 2008 dmueller@suse.de
- update to 2.6.1-RC15:
  * FindMPI: Use the HINTS feature of find_library to find the right
  libraries for MPI, and act a bit more intelligently when MPI cannot be found.
  * moved CMAKE_CROSSCOMPILING from "Variables that modify behaviour" to
  "variables that Provide Information"
  * handle HTML documentation for single items better: no warning about
  * ComputeSectionLinkPrefix, don't create an index for only one item.
  * Better error messages in CPackBundleGenerator
  * Fix bug 7426 FindJPEG module causes error when setting JPEG_LIBRARY to blank
  * Fix bug 7414 PackageMaker generator crashes when given components
    with circular dependencies
  * Fix source files to not add extra /, and look for extensions for
    all enabled languages.
* Mon Jul 21 2008 dmueller@suse.de
- update to 2.6.1-RC11:
  * FindBoost can now find the upcoming Boost 1.46
  * More fixes for CPack components functionality
  * Fix FindQt4.cmake with empty qconfig.pri files.  Fixes #7287.
  * Fix column width in cmake-gui
* Wed Jul  2 2008 dmueller@suse.de
- update to 2.6.1-RC6:
  * Fix DEFINITIONS property to be compatible with 2.4
  * FindGettext.cmake  fix bug #7230: don't ignore first parameter if it's
    not ALL
  * Add support for component based packages in cpack.
  * Fix FindKDE3.cmake to not add flags if kde3 is not found
  * Fix FindMatlab.cmake, FindOpenSSL.cmake, FindQt3.cmake,
    FindSWIG.cmake, to only error if it is required
  * Change to find_*, a new HINTS keyword was added to avoid the
    need for NO_DEFAULT_PATH, and a repeated call to find_*
  * Update all NO_DEFAULT_PATH usage in Modules/Find*
  * Fix for cpack self extracting .sh files to work with more shells
  * FindQt4 now finds dependencies for some qt modules
  * Give a message if rpath is changed during install
  * rpath changer during install understands symlinks now
  * FindQt4 - make Qt not found if the QtCore library can't be found.
  * UseQt4 - only add flags for modles that are used
  * Fix incorrect extension extraction in gcc cross compiler check
  * Add a way to modify depend scanning with the property:
    IMPLICIT_DEPENDS_INCLUDE_TRANSFORM
  * Fix -Wno-dev to not eat path to source tree
  * Fix FindBoost version variable names to correct bug in Boost version
  * Fix bug 0006990 CMake crashes with bad input to
    set_source_files_properties
  * Fix bug in FindCurses where you could not run cmake twice
* Thu Jun 12 2008 mrdocs@opensuse.org
- add %%ifdefs to disable the cmake gui for non-Suse distros
- SLES 9 does not build, but its a compile failure
* Fri May  9 2008 dmueller@suse.de
- fix ctest reporting (kitware#6988), patch by Andreas Schneider
* Tue May  6 2008 dmueller@suse.de
- update to 2.6.0:
  * Fix links in generated documentation
  * Fix for FindQt and some mac frameworks
  * Fix for ctest to report more than 2 gigs system memory on windows
  * Fix CTest build name for vs 9, and fix memory size on windows
* Fri May  2 2008 dmueller@suse.de
- update to 2.6.0 RC10:
  - Do not duplicate .so libraries on the link line
  - Add more system library paths to sun builds
  - Add BETA support for Intel Fortran IDE files in visual studio
  - Fix FindCurses to work if ncurses is the only option
  - Fix shell escapes on some systems
  - Remove check for file write as input to cmake, as it is no longer needed
  - Make check_type_size automatically check for headers that it uses
  - Remove minimum required from FindBoost.cmake
  - Fix FindSDL so that it can be run more than once
  - Fix find required for VTK package
  - Allow for CMAKE_OSX_SYSROOT to work with single architecture
  - Add context information when a source file cannot be found.
  - Report the directory-level context even if no list file
  is currently being processed.
* Mon Apr 28 2008 dmueller@suse.de
- fix curses detection (readds previously lost ccmake)
* Thu Apr 24 2008 dmueller@suse.de
- update to 2.6.0 RC9:
  - Fix for fortran mod:: support
  - Fix bug in install command with BUNDLE DESTINATION
  - Make mac install symlinks check for errors
  - Fix for CMP0007, to not warn about empty lists
  - Preserve static libraries when linked multiple times
  - Use c compiler path to find asm compiler
  - Allow RC compiler to not get all COMPILE_FLAGS
  - Complete overhaul for FindBoost.cmake
  - Minor fixes for FindMPI.cmake
  - Fix for list command and empty list elements CMP0007
  - Fix for VS6 and sub-groups
  - Fix bug 6440, and make sure _INIT flags do not overright cache values
  - Do not report CMP0003 for anything other than -l
  - Fix crash in fortran depend scanning, bug 6855
  - Fix timeout values for cmake's own tests
  - Better message in compiler ABI detect
  - Fixes for cpack x11 packages on leopard
  - Changes to cpack options names
  - Fixes for FindMPI on 64 bit MS MPI
  - Fix for -isystem for wxWidgets
  - Some fixes for chrpath during installation
  - Fix compatibility with CMake 2.4 for installation of MACOSX_BUNDLE (CMP0006)
  - Do not use debug postfix when building frameworks on the Mac
  - Fix exception handling off/on issue with visual studio IDE generators
  - Fix <OBJECT_DIR> to be native path style
  - Fix leak in cpack
  - Some Qt GUI style changes
* Sat Apr 19 2008 dmueller@suse.de
- fix python lib detection again
* Mon Apr 14 2008 dmueller@suse.de
- update to 2.6.0 RC8:
  * Fix sun make very poor performance
  * Fix includes for automoc in FindQt4
* Wed Apr  9 2008 dmueller@suse.de
- update to 2.6.0 RC6:
  * last RC before 2.6.0
  * new graphical cmake ui
  * faster install
* Fri Feb 29 2008 adrian@suse.de
- use rpm macros for pathes
- fix build for Mandriva
* Fri Feb  1 2008 pcerny@suse.cz
- spec file update to build in BS in all distributions
* Mon Jan 28 2008 dmueller@suse.de
- update to 2.4.8:
  * version number increase, no linux specific changes
* Fri Jan 25 2008 pcerny@suse.cz
- added zlib to BuildRequires
* Mon Jan 21 2008 coolo@suse.de
- always buildrequire openssl-devel
* Mon Jan 14 2008 dmueller@suse.de
- update to 2.4.8-RC12:
  * fix glib and Qt4 detection on 10.2 and older
  * MODULE install with versions was broken
* Thu Jan  3 2008 dmueller@suse.de
- update to 2.4.8-RC9:
  * last release candidate of 2.4.8
  * Add list(FIND) because it is used in new FindQt4.cmake
  * Fix tar long file path issue with cpack
  * Fix variable name in docs for FindPkgConfig bug 5722
  * Fix for bug 5645 ifort bad pic flag on linux
  * Fix for bug 6006 INSTALL DIRECTORY signature problem
  * Update FindQt4 from CVS Head for many bug fixes
  * Fix bug 5638 CMAKE_INSTALL_PREFIX not working on SunOS with CC
  * Fix bug 6117 FindPkgConfig can run twice now
  * Fix bug 6106 FindPerlLibs.cmake missing escaped $
  * Allow NODEFAULTLIBS to have more than one value bug 5455
  * fix for bug 5363: GET_TARGET_PROPERTY(... DEBUG_LOCATION)
  * Better error from ctest if nightly time not set
  * Avoid relinking exclude-from-all directory targets before install
  * Fix for kde4-config location
  * Remove KDE3_ENABLE_FINAL (did not work)
  * KDE3 fix for 64 bit location of plugins
  * mark PYTHON_EXECUTABLE as advanced
  * documentation fix for file, find_package, try_run
  * add IS_ABSOLUTE to if
  * INSTALL() everything which doesn't have a COMPONENT set, is assigned
  * make #cmakedefine output match autoconf when undefined
  * document cmake remove -f
  * document order of -D and -P
* Mon Dec 10 2007 dmueller@suse.de
- if you want cmake, you probably also want make
* Fri Sep 21 2007 dmueller@suse.de
- disabling less_verbosity patch
* Fri Jul 20 2007 pcerny@suse.cz
- update to 2.4.7 - several bugfixes
  (KDevelop problem among others,
  see ChangeLog.manual for more details)
* Fri Apr 27 2007 dmueller@suse.de
- expat -> libexpat-devel
* Thu Mar 29 2007 dmueller@suse.de
- add ncurses-devel buildrequires
* Thu Jan 11 2007 dmueller@suse.de
- update to 2.4.6:
  * Fix for FIND_* order and framworks with PREFIX usage.
  * Fix for FindDoxygen and quiet mode.
  * Find JavaVM as well as jvm
  * Look for ruby1.8 and ruby
  * Fix for cpack .tgz.sh and dash
  * Fix for finding custom commands from a full path with CMAKE_CFG_INTDIR.
  * Fix for Borland make and custom commands that do nothing
* Mon Jan  8 2007 dmueller@suse.de
- readd patch to detect shared python library instead of
  the static one.
* Tue Dec 19 2006 mrueckert@suse.de
- added cmake-2.4.5_use_intree_xmlrpc.patch:
  the xmlrpc-c check seems broken. and on 10.2 we dont have the lib
  anyways. so disable the systemwide xmlrpc for now.
* Fri Dec 15 2006 mrueckert@suse.de
- update to version 2.4.5:
  * Fix for seg fault when a macro runs a bad command BUG# 3815
  * Fix fix for foo.dll.lib that does not break -L/usr/lib in
    link names
  * Fix problem with LIBRARY_OUTPUT_PATH and linking to a dll
    foo.dll.lib instead of foo.lib
  * Do not depend on optimized libraries for a debug build and
    visa versa.
  * Fix target name matching custom command output conflict.
  * Fix FindQt3 so that it does not find qt4
  * Fix FindKDE4 so that it only looks for kde4-config
- disabled all patches -> applied upstream
* Mon Oct  2 2006 dmueller@suse.de
- detect shared python library instead of static variant
* Tue Sep 26 2006 dmueller@suse.de
- add python 2.5 support
* Sat Sep  9 2006 dmueller@suse.de
- build against system zlib / libcurl
* Mon Aug 28 2006 coolo@suse.de
- fix Qt3 configure check for lib64
* Sat Aug 26 2006 coolo@suse.de
- respect DESTDIR on installing kde3 icons
* Mon Aug 14 2006 coolo@suse.de
- add SUSE default paths for Qt3
* Mon Jul 31 2006 dmueller@suse.de
- 2.4.3 update:
  * progress is now reported with makefiles
  * Fix relative path problems in ADD_SUBDIRECTORY
  * Fix crash in CMakeSetup when status line is long
  * make sure try compile files have a newline at the end
  * add rxvt-unicode, cygwin, and screen terminal support for color
  output
* Wed May 17 2006 dmueller@suse.de
- 2.4.2 update:
  * Run symlink command from correct directory for executable versions
  * Fix for universal binaries and Xcode depend problem
  * Changes to LIST command, see --help-command LIST
  * Fix FindQT to be able to use full paths to source files
  * Fix CPack ZIP on windows command line problem
  * Find executables with no extension on windows mingw
  * Fix FindQt3 to use QTDIR over path
  * Significant speedup in try-compile for nmake
  * CPack improvements including tar bzip2
  * FindQt4 windows path fix
  * Sunos cc optimize flags are correct
  * Fix crash with ${} empty variable
  * Increase depend speed on Mac OS.
  * install command CONFIGURATIONS option.
  * Fix MSVC60, MSVC70, MSVC71, MSVC80 definitions for IDE builds
  * Fix for C++ compiler being used for c code in VS IDE
* Wed May 10 2006 dmueller@suse.de
- 2.4.1 update :
  * Several ctest and cpack bug fixes
  * Many updates and fixes for FindQt4.cmake
  * Fix CMAKE_REQUIRED_FLAGS in CheckCXXSourceCompiles.cmake
  * Handle running make from a symlinked build tree
  * Automatic color ouput detection for shells building with make
  * Kdevelop generator handles CMakeFiles directory better
  * add correct depend information for fluid
  * allow the cache to be saved even if a fatal error occurs
  * fix bug in relative path subdir and add_subdirectoy commands
  * support in vs for two object files with the same name
  * short file names used for library paths in visual studio
  * package target only shows up when you have cpack config files
  * Use dl and not -ldl for adding in the dynamic library
  * Fix check c/cxx source compiles macros to not clobber log files
  * Fix nmake version detection of cl and create correct pdb files
  * Fix msys bootstrap
  * Change color output to be more readable
  * Fix vs6 library naming
* Tue Apr 18 2006 dmueller@suse.de
- update to 2.4.0, fixes -L/-I compiler flag ordering
  needed for building KDE 4 trunk.
* Thu Apr 13 2006 dmueller@suse.de
- fix --help-modules / --help-module <module>
* Mon Mar 27 2006 dmueller@suse.de
- compile with RPM_OPT_FLAGS (#160857)
- fix permissions of installed files (#160856)
* Fri Mar 24 2006 dmueller@suse.de
- drop rpath patch, no longer necessary
* Mon Mar 20 2006 dmueller@suse.de
- CVS snapshot update, fixes RPATH handling
* Wed Feb 15 2006 dmueller@suse.de
- Initial package (2.3 CVS snapshot 20060210)
